# from http://gnuvince.wordpress.com/2007/09/14/a-django-template-tag-for-the-current-active-page/
from django import template
register = template.Library()

@register.simple_tag
def active(request, pattern, regex=False):
    import re
    if not regex:
        pattern = "^%s$" % pattern
    if re.search(pattern, request.path):
        return 'active'
    return ''



import os

from django.http import Http404
from django.template import loader, TemplateDoesNotExist
from django.views.generic import TemplateView

class StaticpagesView(TemplateView):
    base_directory = ''
    def get_template_names(self):
        url_path = self.args[0].strip('/')
        if '..' in os.path.split(url_path):
            raise Http404
        dir_template = os.path.join(self.base_directory, url_path, 'index.html')
        page_template = os.path.join(self.base_directory, url_path + '.html')
        template_names = [dir_template, page_template]
        try:
            loader.select_template(template_names)
        except TemplateDoesNotExist:
            raise Http404
        return template_names



#!/usr/bin/env python

import os

from django.test import TestCase
from django.test.client import Client
from django.conf import settings
from django.core.urlresolvers import reverse

class URLTest(TestCase):
    urls = 'staticpages.tests.urls'
    def setUp(self):
        self.c = Client()
        settings.TEMPLATE_DIRS = [
            os.path.join(os.path.dirname(__file__), 'templates')
        ]
        settings.STATICPAGES_TEMPLATES = [
            ('homesite', '', 'my_static_site'),
            ('subsite', 'subsite_url', 'my/sub/site'),
        ]

    def tearDown(self):
        del self.c

    def test_basic_functionality(self):
        response = self.c.get('/about/')
        self.assertEqual(response.status_code, 200)
        self.assertTrue('about' in response.content)

    def test_index(self):
        response = self.c.get('/')
        self.assertEqual(response.status_code, 200)
        self.assertTrue('index' in response.content)

    def test_index_name(self):
        self.assertEqual(reverse('homesite', args=['']), '/')

    def test_name(self):
        self.assertEqual(reverse('homesite', args=['about/']), '/about/')

    def test_subsite_index_name(self):
        self.assertEqual(reverse('subsite', args=['']), '/subsite_url/')

    def test_subsite_name(self):
        self.assertEqual(reverse('subsite', args=['page/']), '/subsite_url/page/')

    def test_subdir_index_name(self):
        self.assertEqual(reverse('homesite', args=['subdir/']), '/subdir/')

    def test_subdir_page_name(self):
        self.assertEqual(reverse('homesite', args=['subdir/subpage/']), '/subdir/subpage/')

    def test_404(self):
        response = self.c.get('/does/not/exist')
        self.assertEqual(response.status_code, 301)
        response = self.c.get('/does/not/exist', follow=True)
        self.assertEqual(response.status_code, 404)

    def test_subsite(self):
        response = self.c.get('/subsite_url/')
        self.assertEqual(response.status_code, 200)
        self.assertTrue('subsite' in response.content)

    def test_subsite_page(self):
        response = self.c.get('/subsite_url/page')
        self.assertEqual(response.status_code, 301)
        response = self.c.get('/subsite_url/page', follow=True)
        self.assertEqual(response.status_code, 200)
        self.assertTrue('page' in response.content)

    def test_subdir(self):
        response = self.c.get('/subdir')
        self.assertEqual(response.status_code, 301)
        response = self.c.get('/subdir', follow=True)
        self.assertEqual(response.status_code, 200)
        self.assertTrue('subdir' in response.content)

    def test_subdir_page(self):
        response = self.c.get('/subdir/subpage')
        self.assertEqual(response.status_code, 301)
        response = self.c.get('/subdir/subpage', follow=True)
        self.assertEqual(response.status_code, 200)
        self.assertTrue('subpage' in response.content)

    def test_escape(self):
        response = self.c.get('/subsite_url/../inaccessible', follow=True)
        self.assertEqual(response.status_code, 404)

def main():
    unittest.main()

if __name__ == '__main__':
    main()



import os

from django.conf.urls.defaults import patterns, url
from django.conf import settings
from django.views.generic import TemplateView

from .views import StaticpagesView

def make_pattern(name, base_url, d):
    """ create url pattern for the given name and base url

        patterns should match the base url plus zero or more non-
        matching, non-greedy, groups of one of more characters,
        plus a trailing slash:

        '^{{BASE_URL}}/((?:.+?/)*)$
    """
    #parts = [base_url.strip('/'), '(.*?)/?$']
    parts = [base_url.strip('/'), '((?:.+?/)*)$']
    re = '^' + '/'.join(p for p in parts if p)
    return url(re,
        StaticpagesView.as_view(base_directory=d), name=name)

STATICPAGES_TEMPLATES = getattr(settings, 'STATICPAGES_TEMPLATES', [])
# reorder to not eclipse the longer, more specific, regexes
STATICPAGES_TEMPLATES.sort(key=lambda x: (-len(x[1].split('/')), -len(x[1])))

urlpatterns = patterns('',
    *[make_pattern(name, base_url, base_dir) for name, base_url, base_dir in STATICPAGES_TEMPLATES]
)



from setuptools import setup

setup(
    name='django-staticpages',
    version='0.2.3',
    packages=['staticpages', 'staticpages.tests', 'staticpages.templatetags'],
    include_package_data=True,
    author='Gabriel Grant',
    author_email='g@briel.ca',
    license='LGPL',
    long_description=open('README').read(),
    url='http://github.org/gabrielgrant/django-staticpages/',
)

